@@ -274,7 +274,7 @@ read_string (FILE *fp,
              gsize len)
 {
 	gchar *buf;
-	gint rv;
+	size_t rv;
 
 	/* Avoid overflow for the nul byte. */
 	if (len == G_MAXSIZE)
@@ -282,8 +282,8 @@ read_string (FILE *fp,
 
 	buf = g_new0 (char, len + 1);
 
-	rv = fread (buf, len, 1, fp);
-	if (rv != 1) {
+	rv = fread (buf, sizeof (gchar), len, fp);
+	if (rv != len) {
 		g_free (buf);
 		return NULL;
 	}
@@ -541,8 +541,8 @@ static gboolean
 e_book_backend_summary_save_magic (FILE *fp)
 {
 	gint rv;
-	rv = fwrite (PAS_SUMMARY_MAGIC, PAS_SUMMARY_MAGIC_LEN, 1, fp);
-	if (rv != 1)
+	rv = fwrite (PAS_SUMMARY_MAGIC, sizeof (gchar), PAS_SUMMARY_MAGIC_LEN, fp);
+	if (rv != PAS_SUMMARY_MAGIC_LEN)
 		return FALSE;
 
 	return TRUE;
@@ -570,13 +570,14 @@ static gboolean
 save_string (const gchar *str,
              FILE *fp)
 {
-	gint rv;
+	size_t rv, len;
 
 	if (!str || !*str)
 		return TRUE;
 
-	rv = fwrite (str, strlen (str), 1, fp);
-	return (rv == 1);
+	len = strlen (str);
+	rv = fwrite (str, sizeof (gchar), len, fp);
+	return (rv == len);
 }
 
 static gboolean
