@@ -24,6 +24,7 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#include "camel.h"
 #include <camel/camel-enumtypes.h>
 #include <camel/camel-network-settings.h>
 #include <camel/camel-service.h>
@@ -214,6 +215,9 @@ network_service_accept_certificate_cb (GTlsConnection *connection,
 	gchar *host;
 
 	session = camel_service_ref_session (CAMEL_SERVICE (service));
+	if (!session)
+		return FALSE;
+
 	settings = camel_service_ref_settings (CAMEL_SERVICE (service));
 
 	network_settings = CAMEL_NETWORK_SETTINGS (settings);
@@ -308,13 +312,15 @@ network_service_notify_host_reachable (CamelNetworkService *service)
 
 	session = camel_service_ref_session (CAMEL_SERVICE (service));
 
-	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT_IDLE,
-		network_service_notify_host_reachable_cb,
-		g_object_ref (service),
-		(GDestroyNotify) g_object_unref);
+	if (session) {
+		camel_session_idle_add (
+			session, G_PRIORITY_DEFAULT_IDLE,
+			network_service_notify_host_reachable_cb,
+			g_object_ref (service),
+			(GDestroyNotify) g_object_unref);
 
-	g_object_unref (session);
+		g_object_unref (session);
+	}
 }
 
 static void
@@ -414,6 +420,9 @@ network_service_update_host_reachable (CamelNetworkService *service)
 	priv = CAMEL_NETWORK_SERVICE_GET_PRIVATE (service);
 
 	session = camel_service_ref_session (CAMEL_SERVICE (service));
+	if (!session)
+		return;
+
 	if (!camel_session_get_online (session)) {
 		g_object_unref (session);
 		return;
@@ -536,7 +545,7 @@ network_service_connect_sync (CamelNetworkService *service,
 	if (method == CAMEL_NETWORK_SECURITY_METHOD_SSL_ON_ALTERNATE_PORT)
 		g_socket_client_set_tls (client, TRUE);
 
-	g_object_bind_property (
+	camel_binding_bind_property (
 		service, "proxy-resolver",
 		client, "proxy-resolver",
 		G_BINDING_SYNC_CREATE);
