@@ -1602,7 +1602,7 @@ camel_vee_folder_get_location (CamelVeeFolder *vf,
 
 		vfinfo = (CamelVeeMessageInfo *) camel_folder_get_message_info (folder, camel_message_info_uid (vinfo) + 8);
 		res = camel_vee_folder_get_location ((CamelVeeFolder *) folder, vfinfo, realuid);
-		camel_message_info_unref ((CamelMessageInfo *) vinfo);
+		camel_message_info_unref ((CamelMessageInfo *) vfinfo);
 		return res;
 	} else {
 		if (realuid)
